// CHKCON - check the console jumper
//
// Checks the state of the JP2 jumper and reports it in the DOS ERRORLEVEL
//
// Currently resets the PS-4100 only, but this function will probably be 
// added to the TS-2100/2200/2800 series
//
// cjd	20001004	Created
//

//#include <iostream.h>
#include <stdio.h>
#include <stdlib.h>
#include <dos.h>

const char VER[] = "RESET ver. 1.0, (c) 2000 Technologic Systems Inc.";

const	int UCSADL	= 0xF438;
const	int UCSADH	= 0xF43A;
const	int UCSMSKL	= 0xF43C;
const	int UCSMSKH	= 0xF43E;

const 	int WDTCLR	= 0xF4C8;
const 	int WDTRLDH 	= 0xF4C0;
const 	int WDTRLDL	= 0xF4C2;

// 
// reset	- does the actual work
//
// inputs
//	method	- which specific method to use:
//		1 - config UCS, use port92
//
void reset(int method)
{

	// set UCS to 32-64MB, so that when the processor is reset, the 
	// bios code will be available to restart things..
	// we need to do this because the port92 reset only resets the
	// 386 cpu core -- none of the on-chip peripherals are affected.
	printf("Setting UCS to 32 - 64MB..\n");
	outport(UCSADL, 0x0505);
	outport(UCSADH, 0x0200);
  	outport(UCSMSKL, 0xFC01);
  	outport(UCSMSKH, 0x01FF);

	printf("Resetting EPC using method %i:\n", method);

	switch (method) {
	case 1:
		// now reset the cpu core 
		printf("boom!\n");
		outport(0x92, 0x00);
		outport(0x92, 0x01);
		outport(0x92, 0x00);
		outport(0x92, 0x01);
		outport(0x92, 0x00);
		break;
	
	case 2:
		// reset with WDT
		outport(WDTRLDH, 0x0000);
		outport(WDTRLDL, 0x0020);
		outport(WDTCLR, 0xF01E);	// lockout seq. word 1
		outport(WDTCLR, 0x0FE1);	// lockout seq. word 2
		break;
	}

	printf("0987654321\n");
	exit(1);
}	

	
int main()
{
	reset(2);
	
	return(1);	                // error condition..
}
